# TACC CMS - Templates - DjangoCMS Blog

The templates in this directory are used by:
- _both_ the `djangocms_blog` app pages to show content
- _and_ the `djangocms_blog` app plugins to add content

The templates come from [`nephila/djangocms-blog`:`/djangocms_blog/templates/djangocms_blog`](https://github.com/nephila/djangocms-blog/tree/1.1.1/djangocms_blog/templates/djangocms_blog).

## Reference

- [(TACC) User Guide - Blog & News](https://confluence.tacc.utexas.edu/x/EwDeCg)
- [(TACC) Developer Guide - Blog & News](https://confluence.tacc.utexas.edu/x/8LXtDg)
